@@ -267,7 +267,8 @@ fork_prog (void)
     }
   else if (pid > 0)
     {
-      printf ("(pid %d)\n", (int) pid);
+/*      printf ("(pid %d)\n", (int) pid);
+ */
       exit (EXIT_SUCCESS);
     }
 }
